km3pipe.io.EventPump
====================

.. currentmodule:: km3pipe.io

.. autoclass:: EventPump

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~EventPump.__init__
      ~EventPump.add
      ~EventPump.blob_generator
      ~EventPump.close
      ~EventPump.close_file
      ~EventPump.configure
      ~EventPump.expose
      ~EventPump.extract_event
      ~EventPump.finish
      ~EventPump.get
      ~EventPump.next
      ~EventPump.open_file
      ~EventPump.pre_finish
      ~EventPump.process
      ~EventPump.require
      ~EventPump.rewind_file
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~EventPump.name
   
   